package etm;
import static robocode.util.Utils.normalRelativeAngleDegrees;
import robocode.Robot;
import robocode.ScannedRobotEvent;

/**
 * Creates a stationary robot that tracks a 
 * single target using only the gun
 * Some code has been adapted from sample robot Tracker
 * @author Edward Meyer
 */
public class Firing04 extends Robot {
	
	int count = 0; // Keeps track of how long we've
				   // been searching for our target
	double gunTurnAmt; // How much to turn our gun when searching
	String trackName; // Name of the robot we're currently tracking
	
	/**
	 * Sample robot Tracker's run()
	 * run:  Tracker's main run function
	 */
	public void run() {
		while (true) {
			// Loop forever
			while (true) {
				// turn the Gun (looks for enemy)
				turnGunRight(gunTurnAmt);
				// Keep track of how long we've been looking
				count++;
				// If we've haven't seen our target for 2 turns, look left
				if (count > 2) {
					gunTurnAmt = -10;
				}
				// If we still haven't seen our target for 5 turns, look right
				if (count > 5) {
					gunTurnAmt = 10;
				}
				// If we *still* haven't seen our target after 10 turns, find another target
				if (count > 11) {
					trackName = null;
				}
				
			}
		}
	}
	
	public void onScannedRobot(ScannedRobotEvent e) {
		/* Check to see if scanned robot is current target,
		   go back to scanning if it's not */
		if (trackName != null && !trackName.equals(e.getName())) {return;}
		
		//If robot didn't have a target, it has one now
		if (trackName == null) {trackName = e.getName();}
		
		count = 0; //Target found, reset counter
		
		//Calculate degree to turn towards robot, and do so
		gunTurnAmt = normalRelativeAngleDegrees(e.getBearing() + (getHeading() - getRadarHeading()));
		turnGunRight(gunTurnAmt);
		
		scan();
	}
}
