package etm;
import static robocode.util.Utils.normalRelativeAngleDegrees;
import robocode.Robot;

/**
 * Creates a robot that moves to the center of battlefield
 * then moves in a clock-wise circle
 * @author Edward Meyer
 *
 */
public class Movement06 extends Robot {
	
	public void run() {
		
		//Moves the robot to center
		moveToCenter();
		
		/* Without using Advanced Robot, this uses a loop to turn
		   360 degrees, and 1 degree intervals, and moves ahead 1 pixel */
		for (int i = 1; i<= 360; i++) {
			turnRight(1);
			ahead(1);
		}
	}
	
	/**
	 * Method to move robot to the center of battlefield 
	 * regardless of position
	 */
	private void moveToCenter() {
		//Calculate the center coordinates of battlefield
		double centerY = getBattleFieldHeight() / 2;
		double centerX = getBattleFieldWidth() / 2;
		
		//Get the robots current position
		double currentY = getY();
		double currentX = getX();
		
		
		//Calculate the X and Y distance to move
		double moveX = centerX - currentX;
		double moveY = centerY - currentY;

		/* Use a bit of trigonometry to calculate the angle to turn
		   towards the center of the battlefield */
		/* Whether the robot is positioned below or above the center
		   there's going to be an offset of 180 degrees */
		if (moveY > 0) {
			/* Using static method normalRelativeAngle() and Math class 
			   arctan to calculate the angle to turn towards center */
			turnRight(normalRelativeAngleDegrees(Math.atan(moveX/moveY)*(180/Math.PI)-getHeading()));
		} else {
			turnRight(normalRelativeAngleDegrees(Math.atan(moveX/moveY)*(180/Math.PI)-getHeading()- 180) );
		}
		/* Once robot is faced towards the center, use Pythagorean
		   Theorem to calculate the distance to move */
		ahead(Math.sqrt(Math.pow(moveX, 2) + Math.pow(moveY, 2)));
	}
}
