package etm;
import robocode.Robot;
import robocode.ScannedRobotEvent;
import static robocode.util.Utils.normalRelativeAngleDegrees;

/**
 * Creates a robot that "attempts" to track one robot at a time
 * If the current target dies, will find another target to track
 * Most of this code has been adapted from the sample robot Tracker
 * @author Edward Meyer
 */
public class Tracking01 extends Robot {
	int count = 0; // Keeps track of how long we've
	               // been searching for our target
	double gunTurnAmt; // How much to turn our gun when searching
	String trackName; // Name of the robot we're currently tracking
	
	/**
	 * Sample robot Tracker's run()
	 * run:  Tracker's main run function
	 */
	public void run() {
		// Prepare gun
		trackName = null; // Initialize to not tracking anyone
		setAdjustGunForRobotTurn(true); // Keep the gun still when we turn
		gunTurnAmt = 10; // Initialize gunTurn to 10
		
		// Loop forever
		while (true) {
			// turn the Gun (looks for enemy)
			turnGunRight(gunTurnAmt);
			// Keep track of how long we've been looking
			count++;
			// If we've haven't seen our target for 2 turns, look left
			if (count > 2) {
				gunTurnAmt = -10;
			}
			// If we still haven't seen our target for 5 turns, look right
			if (count > 5) {
				gunTurnAmt = 10;
			}
			// If we *still* haven't seen our target after 10 turns, find another target
			if (count > 11) {
				trackName = null;
			}
	
		}
	}
	
	public void onScannedRobot(ScannedRobotEvent e) {

		// If we have a target, and this isn't it, return immediately
		// so we can get more ScannedRobotEvents.
		if (trackName != null && !e.getName().equals(trackName)) {return;}

		// If robot doesn't have a target, store scanned robot as target
		if (trackName == null) {trackName = e.getName();}
		// This is our target.  Reset count
		count = 0;
		//Calculates degree to turn gun to point to target
		gunTurnAmt = normalRelativeAngleDegrees(e.getBearing() + (getHeading() - getRadarHeading()));

		//Reposition gun and body to point at robot
		turnGunRight(gunTurnAmt);
		turnRight(e.getBearing());

		ahead(e.getDistance()); //move towards target
		
		scan();
	}
}
